@@ -29,4 +29,7 @@ import importlib
 from .modules import *
 from .vis import *
 from .fusion import *
+from .dl.torch.common import print_shape
+from .utils.log import logger
+
 globals().update(importlib.import_module('alfred').__dict__)
\ No newline at end of file
